@@ -7,7 +7,15 @@ use strict;
 use utf8;
 use warnings qw(all);
 
+use Digest::SHA qw(sha256_base64);
 use Moo;
+use MooX::Types::MooseLike::Base qw(
+    ArrayRef
+    HashRef
+    Object
+    Str
+);
+use URI;
 
 extends 'AnyEvent::Net::Curl::Queued';
 
@@ -15,10 +23,28 @@ use YADA::Worker;
 
 no if ($] >= 5.017010), warnings => q(experimental);
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
+
+has _queue      => (
+    is          => 'ro',
+    isa         => ArrayRef[Object],
+    default     => sub { [] },
+);
+
+has _unique_url => (
+    is          => 'ro',
+    isa         => HashRef[Str],
+    default     => sub { {} },
+);
 
 # serious DWIMmery ahead!
-around qw(append prepend) => sub {
+
+## no critic (RequireArgUnpacking)
+around append   => sub { _dwim(append => @_) };
+around prepend  => sub { _dwim(prepend => @_) };
+
+sub _dwim {
+    my $type = shift;
     my $orig = shift;
     my $self = shift;
 
@@ -44,16 +70,38 @@ around qw(append prepend) => sub {
         }
 
         for my $url (@url) {
+            $url = URI->new($url);
+            next
+                if not $self->allow_dups
+                and ++$self->_unique_url->{sha256_base64($url->canonical->as_string)} > 1;
+
             my %copy = %init;
             $copy{initial_url} = $url;
-            $orig->($self => sub { YADA::Worker->new(\%copy) });
+            if ($type eq q(append)) {
+                push    @{$self->_queue} => [ $type => \%copy ];
+            } elsif ($type eq q(prepend)) {
+                unshift @{$self->_queue} => [ $type => \%copy ];
+            }
         }
     } else {
         $orig->($self => @_);
     }
 
     return $self;
-};
+}
+
+sub _shift_worker {
+    my ($self) = @_;
+    my $queue = $self->_queue;
+    my $max = $self->max << 2;
+    while (@{$queue} and ($self->count < $max)) {
+        my ($type, $params) = @{shift @{$queue}};
+        $self->$type(sub { YADA::Worker->new($params) });
+    }
+    return;
+}
+
+before wait => sub { shift->_shift_worker };
 
 
 1;
@@ -70,7 +118,7 @@ YADA - "Yet Another Download Accelerator": alias for AnyEvent::Net::Curl::Queued
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
