@@ -3,14 +3,15 @@ use strict;
 use utf8;
 use warnings qw(all);
 
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(InstanceOf Int Num Str);
 
 extends 'AnyEvent::Net::Curl::Queued::Easy';
 
-has attr1 => (is => 'ro', isa => 'Num', required => 1);
-has attr2 => (is => 'ro', isa => 'Int', required => 1);
-has attr3 => (is => 'rw', isa => 'URI');
-has attr4 => (is => 'rw', isa => 'Str', default => 'A');
+has attr1 => (is => 'ro', isa => Num, required => 1);
+has attr2 => (is => 'ro', isa => Int, required => 1);
+has attr3 => (is => 'rw', isa => InstanceOf['URI']);
+has attr4 => (is => 'rw', isa => Str, default => sub { 'A' });
 
 around clone => sub {
     my $orig = shift;
@@ -31,7 +32,4 @@ around has_error => sub {
     return 1;
 };
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
